@@ -140,7 +140,7 @@ class OTPViewSet(viewsets.GenericViewSet):
                 {
                     "refresh": str(refresh),
                     "access": str(refresh.access_token),
-                    "user": UserSerializer(user).data,
+                    "user": UserSerializer(user, context={'request': request}).data,
                 },
                 status=status.HTTP_200_OK,
             )
