@@ -1,9 +1,11 @@
 """
-Balance and transaction models for the Universal Payment System v2.0.
+Balance and transaction models for Payments v2.0.
 
-Handles user balances and transaction history with atomic operations.
+ORM-based balance calculation from transactions.
 """
 
+from decimal import Decimal
+
 from django.contrib.auth import get_user_model
 from django.core.exceptions import ValidationError
 from django.core.validators import MinValueValidator
@@ -16,42 +18,42 @@ User = get_user_model()
 
 class UserBalance(models.Model):
     """
-    User balance model with atomic operations.
-    
-    Tracks user balance in USD (float for performance as per requirements).
-    All balance updates are handled via Django signals for consistency.
+    User balance model.
+
+    Balance is calculated from Transaction records via ORM aggregation.
+    This model stores the computed balance for performance.
     """
 
     user = models.OneToOneField(
         User,
         on_delete=models.CASCADE,
-        related_name='payment_balance',
+        related_name='payment_balance_v2',
         help_text="User who owns this balance"
     )
 
-    balance_usd = models.FloatField(
-        default=0.0,
-        validators=[MinValueValidator(0.0)],
-        help_text="Current balance in USD (float for performance)"
-    )
-
-    reserved_usd = models.FloatField(
-        default=0.0,
-        validators=[MinValueValidator(0.0)],
-        help_text="Reserved amount in USD (pending transactions)"
+    balance_usd = models.DecimalField(
+        max_digits=10,
+        decimal_places=2,
+        default=Decimal('0.00'),
+        validators=[MinValueValidator(Decimal('0.00'))],
+        help_text="Current balance in USD"
     )
 
     # Tracking fields
-    total_deposited = models.FloatField(
-        default=0.0,
-        validators=[MinValueValidator(0.0)],
+    total_deposited = models.DecimalField(
+        max_digits=10,
+        decimal_places=2,
+        default=Decimal('0.00'),
+        validators=[MinValueValidator(Decimal('0.00'))],
         help_text="Total amount deposited (lifetime)"
     )
 
-    total_spent = models.FloatField(
-        default=0.0,
-        validators=[MinValueValidator(0.0)],
-        help_text="Total amount spent (lifetime)"
+    total_withdrawn = models.DecimalField(
+        max_digits=10,
+        decimal_places=2,
+        default=Decimal('0.00'),
+        validators=[MinValueValidator(Decimal('0.00'))],
+        help_text="Total amount withdrawn (lifetime)"
     )
 
     last_transaction_at = models.DateTimeField(
@@ -79,11 +81,7 @@ class UserBalance(models.Model):
         constraints = [
             models.CheckConstraint(
                 condition=models.Q(balance_usd__gte=0.0),
-                name='balance_non_negative_check'
-            ),
-            models.CheckConstraint(
-                condition=models.Q(reserved_usd__gte=0.0),
-                name='reserved_non_negative_check'
+                name='payments_balance_non_negative_check'
             ),
         ]
 
@@ -94,8 +92,6 @@ class UserBalance(models.Model):
         """Validate balance data."""
         if self.balance_usd < 0:
             raise ValidationError("Balance cannot be negative")
-        if self.reserved_usd < 0:
-            raise ValidationError("Reserved amount cannot be negative")
 
     @property
     def balance_display(self) -> str:
@@ -105,39 +101,24 @@ class UserBalance(models.Model):
     @property
     def is_empty(self) -> bool:
         """Check if balance is zero."""
-        return self.balance_usd == 0.0
+        return self.balance_usd == Decimal('0.00')
 
     @property
     def has_transactions(self) -> bool:
         """Check if user has any transactions."""
         return self.last_transaction_at is not None
 
-    def add_funds(self, amount: float, transaction_type: str = 'deposit',
-                  description: str = None, payment_id: str = None) -> 'Transaction':
-        """Add funds to balance (delegates to manager)."""
-        return self.__class__.objects.add_funds_to_user(
-            self.user, amount, transaction_type, description, payment_id
-        )
-
-    def subtract_funds(self, amount: float, transaction_type: str = 'withdrawal',
-                      description: str = None, payment_id: str = None) -> 'Transaction':
-        """Subtract funds from balance (delegates to manager)."""
-        return self.__class__.objects.subtract_funds_from_user(
-            self.user, amount, transaction_type, description, payment_id
-        )
-
     @classmethod
     def get_or_create_for_user(cls, user: User) -> 'UserBalance':
-        """Get or create balance for user (delegates to manager)."""
-        return cls.objects.get_or_create_for_user(user)
-
-
+        """Get or create balance for user."""
+        balance, created = cls.objects.get_or_create(user=user)
+        return balance
 
 
 class Transaction(UUIDTimestampedModel):
     """
     Transaction record for balance changes.
-    
+
     Immutable record of all balance changes with full audit trail.
     """
 
@@ -153,23 +134,28 @@ class Transaction(UUIDTimestampedModel):
     user = models.ForeignKey(
         User,
         on_delete=models.CASCADE,
-        related_name='payment_transactions',
+        related_name='payment_transactions_v2',
         help_text="User who owns this transaction"
     )
 
     transaction_type = models.CharField(
         max_length=20,
         choices=TransactionType.choices,
+        db_index=True,
         help_text="Type of transaction"
     )
 
-    # Amount in USD (float for performance, positive for credits, negative for debits)
-    amount_usd = models.FloatField(
+    # Amount in USD (Decimal for precision, positive for credits, negative for debits)
+    amount_usd = models.DecimalField(
+        max_digits=10,
+        decimal_places=2,
         help_text="Transaction amount in USD (positive=credit, negative=debit)"
     )
 
-    balance_after = models.FloatField(
-        validators=[MinValueValidator(0.0)],
+    balance_after = models.DecimalField(
+        max_digits=10,
+        decimal_places=2,
+        validators=[MinValueValidator(Decimal('0.00'))],
         help_text="User balance after this transaction"
     )
 
@@ -194,6 +180,15 @@ class Transaction(UUIDTimestampedModel):
         help_text="Additional transaction metadata"
     )
 
+    # Reference to withdrawal request
+    withdrawal_request_id = models.CharField(
+        max_length=100,
+        null=True,
+        blank=True,
+        db_index=True,
+        help_text="Related withdrawal request ID (if applicable)"
+    )
+
     # Manager
     from .managers.balance_managers import TransactionManager
     objects = TransactionManager()
@@ -207,6 +202,7 @@ class Transaction(UUIDTimestampedModel):
             models.Index(fields=['user', 'created_at']),
             models.Index(fields=['transaction_type', 'created_at']),
             models.Index(fields=['payment_id']),
+            models.Index(fields=['withdrawal_request_id']),
             models.Index(fields=['amount_usd']),
         ]
 
