@@ -44,15 +44,18 @@ def get_enabled_cfg_apps() -> List[str]:
     if base_module.is_agents_enabled():
         enabled_apps.append("django_cfg.apps.agents")
 
-    if base_module.should_enable_tasks():
-        enabled_apps.append("django_cfg.apps.tasks")
-
     if base_module.is_payments_enabled():
         enabled_apps.append("django_cfg.apps.payments")
 
     if base_module.is_centrifugo_enabled():
         enabled_apps.append("django_cfg.apps.centrifugo")
 
+    if base_module.should_enable_rq():
+        enabled_apps.append("django_cfg.apps.rq")
+
+    if base_module.is_grpc_enabled():
+        enabled_apps.append("django_cfg.apps.grpc")
+
     return enabled_apps
 
 
@@ -84,7 +87,7 @@ def get_default_cfg_group():
         name="cfg",
         apps=get_enabled_cfg_apps(),
         title="Django-CFG API",
-        description="Authentication (OTP), Support, Newsletter, Leads, Knowledge Base, AI Agents, Tasks, Payments, Dashboard",
+        description="Authentication (OTP), Support, Newsletter, Leads, Knowledge Base, AI Agents, Tasks, Payments, Centrifugo, gRPC, Dashboard",
         version="1.0.0",
     )
 
@@ -173,17 +176,18 @@ APP_URL_MAP = {
     "django_cfg.apps.agents": [
         ("cfg/agents/", "django_cfg.apps.agents.urls"),
     ],
-    "django_cfg.apps.tasks": [
-        ("cfg/tasks/", "django_cfg.apps.tasks.urls"),
-        ("cfg/tasks/admin/", "django_cfg.apps.tasks.urls_admin"),
-    ],
     "django_cfg.apps.payments": [
         ("cfg/payments/", "django_cfg.apps.payments.urls"),
-        # Payments v2.0: No separate urls_admin (uses Django Admin only)
     ],
     "django_cfg.apps.centrifugo": [
         ("cfg/centrifugo/", "django_cfg.apps.centrifugo.urls"),
     ],
+    "django_cfg.apps.rq": [
+        ("cfg/rq/", "django_cfg.apps.rq.urls"),
+    ],
+    "django_cfg.apps.grpc": [
+        ("cfg/grpc/", "django_cfg.apps.grpc.urls"),
+    ],
 }
 
 # Register URLs for enabled apps only
