@@ -22,6 +22,7 @@ from ...models import (
     CacheConfig,
     CryptoFieldsConfig,
     DatabaseConfig,
+    DjangoRQConfig,
     DRFConfig,
     EmailConfig,
     LimitsConfig,
@@ -29,9 +30,9 @@ from ...models import (
     TelegramConfig,
     UnfoldConfig,
 )
+from ...models.api.grpc import GRPCConfig
 from ...models.ngrok import NgrokConfig
 from ...models.payments import PaymentsConfig
-from ...models.tasks import TaskConfig
 from ...modules.nextjs_admin import NextJsAdminConfig
 from ..exceptions import ConfigurationError
 from ..types.enums import EnvironmentMode, StartupInfoMode
@@ -216,9 +217,19 @@ class DjangoConfig(BaseModel):
     )
 
     # === Cache Configuration ===
+    # Redis URL - used for automatic cache configuration if cache_default is not set
+    redis_url: Optional[str] = Field(
+        default=None,
+        description=(
+            "Redis connection URL (redis://host:port/db). "
+            "If set and cache_default is None, automatically creates RedisCache backend. "
+            "Also used by Django-RQ if queues don't specify connection details."
+        ),
+    )
+
     cache_default: Optional[CacheConfig] = Field(
         default=None,
-        description="Default cache backend",
+        description="Default cache backend (auto-created from redis_url if not set)",
     )
 
     cache_sessions: Optional[CacheConfig] = Field(
@@ -312,10 +323,10 @@ class DjangoConfig(BaseModel):
         description="Enable modern Tailwind CSS theme for Django REST Framework Browsable API",
     )
 
-    # === Background Task Processing ===
-    tasks: Optional[TaskConfig] = Field(
+    # === Django-RQ Task Queue & Scheduler ===
+    django_rq: Optional[DjangoRQConfig] = Field(
         default=None,
-        description="Background task processing configuration (Dramatiq)",
+        description="Django-RQ task queue and scheduler configuration (sync tasks, cron scheduling)",
     )
 
     # === Centrifugo Configuration ===
@@ -335,6 +346,11 @@ class DjangoConfig(BaseModel):
         description="Extended DRF Spectacular configuration (supplements OpenAPI Client)",
     )
 
+    grpc: Optional[GRPCConfig] = Field(
+        default=None,
+        description="gRPC framework configuration (server, authentication, proto generation)",
+    )
+
     # === Limits Configuration ===
     limits: Optional[LimitsConfig] = Field(
         default=None,
@@ -618,28 +634,19 @@ class DjangoConfig(BaseModel):
             **kwargs
         )
 
-    def should_enable_tasks(self) -> bool:
+    def should_enable_rq(self) -> bool:
         """
-        Determine if background tasks should be enabled.
+        Determine if Django-RQ should be enabled.
 
-        Tasks are enabled if:
-        1. Explicitly configured via tasks field
-        2. Knowledge base is enabled (requires background processing)
-        3. Agents are enabled (requires background processing)
+        Django-RQ is enabled if explicitly configured via django_rq field.
 
         Returns:
-            True if tasks should be enabled, False otherwise
+            True if Django-RQ should be enabled, False otherwise
         """
-        # Check if explicitly configured
-        if hasattr(self, 'tasks') and self.tasks and self.tasks.enabled:
-            return True
-
-        # Check if features that require tasks are enabled
-        if self.enable_knowbase or self.enable_agents:
+        if hasattr(self, 'django_rq') and self.django_rq and self.django_rq.enabled:
             return True
 
         return False
 
-
 # Export main class
 __all__ = ["DjangoConfig"]
