@@ -23,7 +23,6 @@ class InstalledAppsBuilder:
     - Combine default Django/third-party apps
     - Add django-cfg apps based on enabled features
     - Handle special ordering (accounts before admin)
-    - Auto-enable tasks if needed
     - Auto-detect dashboard apps from Unfold
     - Add project-specific apps
     - Remove duplicates while preserving order
@@ -140,6 +139,9 @@ class InstalledAppsBuilder:
         if self.config.centrifugo and self.config.centrifugo.enabled:
             apps.append("django_cfg.apps.centrifugo")
 
+        if self.config.grpc and self.config.grpc.enabled:
+            apps.append("django_cfg.apps.grpc")
+
         if self.config.crypto_fields and self.config.crypto_fields.enabled:
             apps.append("django_crypto_fields.apps.AppConfig")
 
@@ -158,10 +160,10 @@ class InstalledAppsBuilder:
         """
         apps = []
 
-        # Auto-enable tasks if needed by other features
-        if self.config.should_enable_tasks():
-            apps.append("django_dramatiq")  # Add django_dramatiq first
-            apps.append("django_cfg.apps.tasks")
+        # Add Django-RQ if enabled
+        if hasattr(self.config, "django_rq") and self.config.django_rq and self.config.django_rq.enabled:
+            apps.append("django_rq")  # Core django-rq package
+            apps.append("django_cfg.apps.rq")  # Django-CFG monitoring & API
 
         # Add DRF Tailwind theme module (uses Tailwind via CDN)
         if self.config.enable_drf_tailwind:
